==> igniteui-react-16.16.2.tgz: package/esm5/lib/IconButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ButtonBase } from "./ButtonBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { IconButtonVariant_$type } from "./IconButtonVariant";
/**
 * @hidden
 */
var IconButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IconButton, _super);
    function IconButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(IconButton.prototype, "x", {
        get: function () {
            var ret_ = this.h.c("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IconButton.prototype, "w", {
        get: function () {
            var ret_ = this.h.c("collection");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("collection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IconButton.prototype, "v", {
        get: function () {
            var ret_ = this.h.c("mirrored");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("mirrored", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IconButton.prototype, "u", {
        get: function () {
            var ret_ = this.h.c("variant");
            ret_ = enumGetBox(IconButtonVariant_$type, EnumUtil.getEnumValue(IconButtonVariant_$type, EnumUtil.parse(IconButtonVariant_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(IconButtonVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(IconButtonVariant_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    IconButton.prototype.y = function (a, b, c) {
        this.nativeElement.registerIcon(a, b, c);
    };
    IconButton.prototype.z = function (a, b, c) {
        this.nativeElement.registerIconFromText(a, b, c);
    };
    IconButton.$t = markType(IconButton, 'IconButton', ButtonBase.$);
    return IconButton;
}(ButtonBase));
export { IconButton };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/IconButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ButtonBase } from "./ButtonBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { IconButtonVariant_$type } from "./IconButtonVariant";
/**
 * @hidden
 */
var IconButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IconButton, _super);
    function IconButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(IconButton.prototype, "y", {
        get: function () {
            var ret_ = this.h.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IconButton.prototype, "x", {
        get: function () {
            var ret_ = this.h.n("collection");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("collection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IconButton.prototype, "w", {
        get: function () {
            var ret_ = this.h.n("mirrored");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("mirrored", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IconButton.prototype, "v", {
        get: function () {
            var ret_ = this.h.n("variant");
            ret_ = enumGetBox(IconButtonVariant_$type, EnumUtil.getEnumValue(IconButtonVariant_$type, this.h.f(IconButtonVariant_$type, ret_)));
            return EnumUtil.getEnumValue(IconButtonVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(IconButtonVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    IconButton.prototype.z = function (a, b, c) {
        this.nativeElement.registerIcon(this.h.i(a), this.h.i(b), this.h.i(c));
    };
    IconButton.prototype.aa = function (a, b, c) {
        this.nativeElement.registerIconFromText(this.h.i(a), this.h.i(b), this.h.i(c));
    };
    IconButton.$t = markType(IconButton, 'IconButton', ButtonBase.$);
    return IconButton;
}(ButtonBase));
export { IconButton };
